<?php

/**
* Creates vocabs in code.
*
* @code
* $vocab = CINC::init('TaxonomyVocabulary');
* @endcode
*/
class CINC_TaxonomyVocabulary extends CINC implements CINC_CRUD {

  function __construct() {

    $this->config_filters['machine_name'] = 'set_machine_name';

    // Set defaults.

    $this->config = array(
      'machine_name' => '',
      'name' => '',
      'base' => 'node_content',
      'description' => '',
      'help' => '',
      'custom' => 1,
      'modified' => 1,
      'locked' => 0,
      'disabled' => 0,
      'is_new' => 1,
      'title_label' => 'Title',
    );

    $this->original_config = $this->config;

    return $this;

  }

  /**
   * Auto-adds name when type is set, and cleans type.
   */
  public function set_machine_name($type) {
    if (empty($this->config['name'])) {
      $this->set('name', CINC::display_name_from_machine_name($type));
    }
    return CINC::clean_machine_name($type);
  }

  /**
  * Saves vocab to the database.
  */
  public function create() {
    taxonomy_vocabulary_save($this->config);
    return $this;
  }

  /**
  * Loads vocab from the database.
  */
  public function read() {
    $this->config = taxonomy_vocabulary_machine_name_load($this->config['machine_name']);
    return $this;
  }

  /**
  * Saves vocab to the database.
  */
  public function update() {
    // $this->create();
    taxonomy_taxonomy_vocabulary_update($this->config);
    return $this;
  }

  /**
  * Removes vocab from the database.
  */
  public function delete() {
    return $this;
  }

  public function add_field($field, $weight = NULL) {
    if (!($field instanceof CINC_Field)) {
      throw new Exception('CINC_TaxonomyVocabulary::add_field requires a CINC_Field instance as the first parameter');
    }
    // Use the CINC_Field Class method to save the field to this content type.
    $field->create_instance_for('taxonomy_vocabulary', $this->config['machine_name'], $weight);
    // Add this field to the fields array property.
    if ($is_saved) {
      array_push($field, $this->fields);
    }

    return $this;
  }

}
